==> pyfoldercheck-0.0.3.tar.gz: pyfoldercheck-0.0.3/setup.py <==
import setuptools


def get_readme():
    with open('README.rst') as f:
        return f.read()


setuptools.setup(
    # the first three fields are a must according to the documentation
    name="pyfoldercheck",
    version="0.0.3",
    packages=[
        'pyfoldercheck',
        'pyfoldercheck.endpoints',
    ],
    # from here all is optional
    description="apply a set of checks on files in a folder",
    long_description=get_readme(),
    long_description_content_type="text/x-rst",
    author="Mark Veltzer",
    author_email="mark.veltzer@gmail.com",
    maintainer="Mark Veltzer",
    maintainer_email="mark.veltzer@gmail.com",
    keywords=[
        'mp3',
        'pdf',
        'collection',
    ],
    url="https://veltzer.github.io/pyfoldercheck",
    download_url="https://github.com/veltzer/pyfoldercheck",
    license="MIT",
    platforms=[
        'python3',
    ],
    install_requires=[
        'pytconf',
        'pylogconf',
    ],
    extras_require={
    },
    classifiers=[
        'Development Status :: 4 - Beta',
        'Environment :: Console',
        'Operating System :: OS Independent',
        'Programming Language :: Python',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3 :: Only',
        'Programming Language :: Python :: 3.6',
        'Programming Language :: Python :: 3.7',
        'Programming Language :: Python :: 3.8',
        'Topic :: Utilities',
        'License :: OSI Approved :: MIT License',
    ],
    data_files=[
    ],
    entry_points={"console_scripts": [
        'pyfoldercheck=pyfoldercheck.endpoints.main:main',
    ]},
    python_requires=">=3.6",
)

==> pyfoldercheck-0.0.4.tar.gz: pyfoldercheck-0.0.4/setup.py <==
import setuptools


def get_readme():
    with open('README.rst') as f:
        return f.read()


setuptools.setup(
    # the first three fields are a must according to the documentation
    name="pyfoldercheck",
    version="0.0.4",
    packages=[
        'pyfoldercheck',
    ],
    # from here all is optional
    description="apply a set of checks on files in a folder",
    long_description=get_readme(),
    long_description_content_type="text/x-rst",
    author="Mark Veltzer",
    author_email="mark.veltzer@gmail.com",
    maintainer="Mark Veltzer",
    maintainer_email="mark.veltzer@gmail.com",
    keywords=[
        'mp3',
        'pdf',
        'collection',
    ],
    url="https://veltzer.github.io/pyfoldercheck",
    download_url="https://github.com/veltzer/pyfoldercheck",
    license="MIT",
    platforms=[
        'python3',
    ],
    install_requires=[
        'pytconf',
        'pylogconf',
    ],
    extras_require={
    },
    classifiers=[
        'Development Status :: 4 - Beta',
        'Environment :: Console',
        'Operating System :: OS Independent',
        'Programming Language :: Python',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3 :: Only',
        'Programming Language :: Python :: 3.6',
        'Programming Language :: Python :: 3.7',
        'Programming Language :: Python :: 3.8',
        'Topic :: Utilities',
        'License :: OSI Approved :: MIT License',
    ],
    data_files=[
    ],
    entry_points={"console_scripts": [
        'pyfoldercheck=pyfoldercheck.main:main',
    ]},
    python_requires=">=3.6",
)
